==> release.12.0.73.1.tgz: prontus/cpan/js-local/EditorRobots.class.js <==
var EditorRobots = {
    idEditor: 'ace-editor',
    urlGuardar: 'prontus_edit_guardar.cgi',
    urlBorrar: 'prontus_edit_borrar.cgi',
    urlValidar: 'seo/prontus_validar_robots.cgi',
    editorLoaded: false,
    aceEditor: null,
    textUploadName: '[nombre sin extensión]',

    init: function() {
        // Setea el Path
        var theFile = '/robots.txt';
        EditorRobots.initEditor(theFile);

        $('#form-editor').on('click', '#borrar_archivo', function () {
            EditorRobots.accionBorrar();
            return false;
        });

        $('#form-editor').on("click", '#modal_template_archivo', function () {
            showModalConfirm(modal_template);
        });

        $('#form-editor').on("click", '#modal_guardar_archivo', function () {
            showModalConfirm(modal_guardar);
        });

        $('#form-editor').on("click", '#modal_borrar_archivo', function () {
            showModalConfirm(modal_borrar);
        });
    },

    // -------------------------------------------------------------------------
    initEditor: function(filetype) {
        var my_highlight = "ace/mode/text";

        // Aca se deja el loading
        $('#content-editor').prepend('<div class="list-loading" style="height:100px">&nbsp;</div>');
        // Se inicia el editor
        this.aceEditor = ace.edit("ace-editor");
        this.aceEditor.setOptions({
            mode: my_highlight,
            theme: 'ace/theme/chrome',
            wrapBehavioursEnabled: true,
            wrap:true,
            maxLines: 100,
            minLines: 24,
            useWorker: false
        });
        EditorRobots.initEditorHandler('ace-editor');
    },

    // -------------------------------------------------------------------------
    initEditorHandler: function(id_editor) {
        // Se oculta el loading
        $('#content-editor .list-loading').remove();

        var h = window.innerHeight;
        if (h > 640 && h < 1215) {
            $('#' + EditorRobots.idEditor).css('height', "650px");
        } else if (h < 640) {
            $('#' + EditorRobots.idEditor).css('height', "330px");
        } else if (h >= 1215) {
            $('#' + EditorRobots.idEditor).css('height', "980px");
        }

        // Se usa para saber cuando cargo exactamente el editor
        EditorRobots.editorLoaded = true;
    },

    // -------------------------------------------------------------------------
    accionGuardar: function() {
        if (EditorRobots.loading) {
            return;
        }

        EditorRobots.loading = true;
        EditorRobots.muestraAcciones(false);

        $('#text_file').val(this.aceEditor.getValue());
        $('#sbm_accion').val('Guardar');
        $('#modal-loading').modal();

        var config = {
            formSelector: '#form-editor',
            actionURL: EditorRobots.urlGuardar
        };
        var opts = {
            complete: function() {
                EditorRobots.loading = false;
                EditorRobots.muestraAcciones(true);
                $('#modal-loading').modal('hide');
            },
            success: function(resp) {
                if (resp.status == 1) {
                    showSuccessAlert(".get_message", 'El archivo ha sido guardado de manera exitosa');
                    EditorRobots.accionValidarRobots();
                } else {
                    Admin.displayMessage(resp.msg, 'error');
                }
            }
        };
        SubmitForm.submitGenericAjax(config, opts);
    },

    // -------------------------------------------------------------------------
    accionBorrar: function() {
        if (EditorRobots.loading) {
            return;
        }

        EditorRobots.loading = true;
        EditorRobots.muestraAcciones(false);

        $('#type_item').val('file');
        $('#smb_accion').val('Borrar');
        var dir = $('#_curr_dir').val();
        var config = {
            formSelector: '#form-editor',
            actionURL: EditorRobots.urlBorrar
        };
        var opts = {
            complete: function() {
                EditorRobots.loading = false;
                EditorRobots.muestraAcciones(true);
            },
            success: function(resp) {
                if (resp.status == 1) {
                    EditorRobots.loading = false;
                    showSuccessAlert(".get_message", "El archivo ha sido eliminado");
                } else {
                    showWarningAlert(".get_message", resp.msg);
                }
            }
        };

        SubmitForm.submitGenericAjax(config, opts);
    },
    accionValidarRobots: function() {
        $.get(EditorRobots.urlValidar+"?_prontus_id="+Admin.prontus_id, 
        '', 
        function(data) {
            let results = '';
            let rules = data.results;
            if (rules.length) {
                results = '<p>Reglas válidas encontradas en <a href="/robots.txt" target="_blank">/robots.txt</a>:</p>';
                results +='<ul class="list-group">';
                rules.forEach(element => results += '<li class="list-group-item">'+element+'</li>');
                results += "</ul>";
            } else {
                results = '<p>No se encontraron reglas válidas en robots.txt</p>';
            }
            $('#validacion-robots').html(results);
        },
        'json');
    },
    accionCrearTemplate: function() {
        let template = "#Formato:\n#User-agent: [user-agent] # nombre del crawler\n#Allow: [url]\n#Allow: [otra url] # Para Googlebot: URLs permitidas aunque de otro modo estén dentro de una regla Disallow.\n#Disallow: [url] #URLs que los agentes no deben analizar.\n#Disallow: [otra url] # Pueden agregarse múltiples reglas Allow o Disallow, una por línea.\n#Crawl-delay: [demora] # Tiempo en milisegundos que debe esperar antes de analizar cada página] # Google no respeta este comando, usar crawl-rate en Google Search Console.\n#Sitemap: [url de sitemap] # Para Google, Ask, Bing, Yahoo\n\n#Cada grupo de reglas (User-agent, Allow, Disallow, Crawl-delay) debe estar separado por una linea en blanco\n#User-agent: [otro user-agent]\n#Disallow: [otra regla de URLs que este user-agent no debe analizar]\n#Allow: [otra regla de URLs que Googlebot puede analizar]\n\nUser-agent: * # Cualquier user-agent\nDisallow: #línea vacía: permitir acceso a todo.\n\nSitemap: /"+Admin.prontus_id+"/site/sitemap_pags.xml # Verificar que exista.";
        EditorRobots.aceEditor.setValue(template, -1);
        EditorRobots.accionValidarRobots();
    },

    // -------------------------------------------------------------------------
    muestraAcciones: function(flag) {
        if (!flag) {
            $('.botones-accion .acciones').hide();
            $('.botones-accion .loading-action').fadeIn();
        } else {
            $('.botones-accion .loading-action').hide();
            $('.botones-accion .acciones').fadeIn();
        }
    },

    // -------------------------------------------------------------------------
    selItemCero: function(selectObject) {
        selectObject.options[0].selected = true;
    },

    // -------------------------------------------------------------------------
    validFileName: function(param) {
        var expr = /^([^\\\/:\*\?"><\|\s]+)$/;
        var found = expr.exec(param);
        if (!found) {
            alert('Nombre de archivo no es válido');
            return false;
        }
        return true;
    }
};

==> release.12.3.1.2.tgz: prontus/cpan/js-local/EditorRobots.class.js <==
var EditorRobots = {
    idEditor: 'ace-editor',
    urlGuardar: 'prontus_edit_guardar.cgi',
    urlBorrar: 'prontus_edit_borrar.cgi',
    urlValidar: 'seo/prontus_validar_robots.cgi',
    editorLoaded: false,
    aceEditor: null,
    textUploadName: ProntusL10n.get('editor_filename_no_ext'),

    init: function() {
        // Setea el Path
        var theFile = '/robots.txt';
        EditorRobots.initEditor(theFile);

        $('#form-editor').on('click', '#borrar_archivo', function () {
            EditorRobots.accionBorrar();
            return false;
        });

        $('#form-editor').on("click", '#modal_template_archivo', function () {
            showModalConfirm(modal_template);
        });

        $('#form-editor').on("click", '#modal_guardar_archivo', function () {
            showModalConfirm(modal_guardar);
        });

        $('#form-editor').on("click", '#modal_borrar_archivo', function () {
            showModalConfirm(modal_borrar);
        });
    },

    // -------------------------------------------------------------------------
    initEditor: function(filetype) {
        var my_highlight = "ace/mode/text";

        // Aca se deja el loading
        $('#content-editor').prepend('<div class="list-loading" style="height:100px">&nbsp;</div>');
        // Se inicia el editor
        this.aceEditor = ace.edit("ace-editor");
        this.aceEditor.setOptions({
            mode: my_highlight,
            theme: 'ace/theme/chrome',
            wrapBehavioursEnabled: true,
            wrap:true,
            maxLines: 100,
            minLines: 24,
            useWorker: false
        });
        EditorRobots.initEditorHandler('ace-editor');
    },

    // -------------------------------------------------------------------------
    initEditorHandler: function(id_editor) {
        // Se oculta el loading
        $('#content-editor .list-loading').remove();

        var h = window.innerHeight;
        if (h > 640 && h < 1215) {
            $('#' + EditorRobots.idEditor).css('height', "650px");
        } else if (h < 640) {
            $('#' + EditorRobots.idEditor).css('height', "330px");
        } else if (h >= 1215) {
            $('#' + EditorRobots.idEditor).css('height', "980px");
        }

        // Se usa para saber cuando cargo exactamente el editor
        EditorRobots.editorLoaded = true;
    },

    // -------------------------------------------------------------------------
    accionGuardar: function() {
        if (EditorRobots.loading) {
            return;
        }

        EditorRobots.loading = true;
        EditorRobots.muestraAcciones(false);

        $('#text_file').val(this.aceEditor.getValue());
        $('#action').val('save');
        $('#modal-loading').modal();

        var config = {
            formSelector: '#form-editor',
            actionURL: EditorRobots.urlGuardar
        };
        var opts = {
            complete: function() {
                EditorRobots.loading = false;
                EditorRobots.muestraAcciones(true);
                $('#modal-loading').modal('hide');
            },
            success: function(resp) {
                if (resp.status == 1) {
                    showSuccessAlert(".get_message", ProntusL10n.get('robot_editor_save_success'));
                    EditorRobots.accionValidarRobots();
                } else {
                    Admin.displayMessage(resp.msg, 'error');
                }
            }
        };
        SubmitForm.submitGenericAjax(config, opts);
    },

    // -------------------------------------------------------------------------
    accionBorrar: function() {
        if (EditorRobots.loading) {
            return;
        }

        EditorRobots.loading = true;
        EditorRobots.muestraAcciones(false);

        $('#type_item').val('file');
        var config = {
            formSelector: '#form-editor',
            actionURL: EditorRobots.urlBorrar
        };
        var opts = {
            complete: function() {
                EditorRobots.loading = false;
                EditorRobots.muestraAcciones(true);
            },
            success: function(resp) {
                if (resp.status == 1) {
                    EditorRobots.loading = false;
                    showSuccessAlert(".get_message", ProntusL10n.get('robot_editor_delete_success'));
                } else {
                    showWarningAlert(".get_message", resp.msg);
                }
            }
        };

        SubmitForm.submitGenericAjax(config, opts);
    },
    accionValidarRobots: function() {
        $.get(EditorRobots.urlValidar+"?_prontus_id="+Admin.prontus_id,
        '',
        function(data) {
            let results = '';
            let rules = data.results;
            if (rules.length) {
                results = '<p>' + ProntusL10n.get('robot_editor_rules_found_in') + ' <a href="/robots.txt" target="_blank">/robots.txt</a>:</p>';
                results +='<ul class="list-group">';
                rules.forEach(element => results += '<li class="list-group-item">'+element+'</li>');
                results += "</ul>";
            } else {
                results = '<p>'+ ProntusL10n.get('robot_editor_no_rules_found') +'</p>';
            }
            $('#validacion-robots').html(results);
        },
        'json');
    },
    accionCrearTemplate: function() {
        let template = ProntusL10n.get('robot_editor_template', Admin.prontus_id);
        EditorRobots.aceEditor.setValue(template, -1);
        EditorRobots.accionValidarRobots();
    },

    // -------------------------------------------------------------------------
    muestraAcciones: function(flag) {
        if (!flag) {
            $('.botones-accion .acciones').hide();
            $('.botones-accion .loading-action').fadeIn();
        } else {
            $('.botones-accion .loading-action').hide();
            $('.botones-accion .acciones').fadeIn();
        }
    },

    // -------------------------------------------------------------------------
    selItemCero: function(selectObject) {
        selectObject.options[0].selected = true;
    },

    // -------------------------------------------------------------------------
    validFileName: function(param) {
        var expr = /^([^\\\/:\*\?"><\|\s]+)$/;
        var found = expr.exec(param);
        if (!found) {
            alert( ProntusL10n.get('robot_editor_no_rules_found') );
            return false;
        }
        return true;
    }
};
